#!/bin/sh

set -e

link_file() {
    echo "[0|$1|$2|server|port]"
}

link_ext() {
    echo "[1|$1|$2|$3|port]"n
}

link_www() {
    echo "[h|$1|URL:$2|server|port]"
}

header() {
    lin="$(echo " $@ " | sed 's/./═/g')"
    cat <<EOF
╬$lin╬
║ $@ ║
╬$lin╬
EOF
}

enclose() {
    sed -r -e "s/^/$1/" -e 's/\|?$/'"$2/"
}

{
    cat <<EOF
 ░▒░▒░▒░▒░▒░▒░▒░▒░▒░▒░▒░▒░▒░▒
▒░                          ▒░
EOF

    enclose '▒░  ' '  ▒░' <<EOF
Welcome to            |
                      |
$(echo "Niels'" | toilet -f pagga)
                      |
           gopherhole!
EOF

    cat <<EOF
▒░                          ▒░
 ░▒░▒░▒░▒░▒░▒░▒░▒░▒░▒░▒░▒░▒░▒
EOF
} | enclose '          ' ''

cat <<EOF

       My name is Niels.  I live in Denmark.


$(header Jokes)

I like to create jokes.  As a child I set out to write down all jokes and
riddles I could come up with, and, more importantly, also decided to properly
categorize them.

The categories I created in 2002 were:

  - Garden
  - Work
  - Food
  - Cannibals
  - Books
  - Balls
  - Animals
  - Robbers

I have made a selection of my 2002-era jokes available in translated form:

$(link_file 'My old jokes' 'jokes_2002.txt')

After initial success, I decided to pause my joke categorization work and focus
on other things in life.  Then, in 2007, my mission continued.  At this point I
had learnt how to program with Active Server Pages, which enabled both for a
more structured way of saving jokes and riddles as well as for a more
interactive exploration of joke categories.

During the five years I had also learnt how some jokes and riddles can be
difficult to categorize into single categories.  As such, the second iteration
of my joke database would allow for each joke or riddle to have more than one
category.

I have also made a select few of these 2007-era jokes available in translated
form:

$(link_file 'My slightly less old jokes' 'jokes_2007.txt')

The third iteration of my joke database is still in development.


$(header Other work)

I'm also a computer scientist.  By day I work as a programmer in a Danish
software company.

I attend BornHack every year.  Can recommend!
$(link_www 'BornHack: a 7 day outdoor hacker tent camp in Denmark' 'http://bornhack.dk')

I use NixOS as my operating system on both my laptop and my servers.  I think
it's nice!
$(link_www 'NixOS: Reproducible builds and deployments' 'https://nixos.org/')

This gopherhole uses geomyidae as its Gopher daemon, configured in Nix:
$(link_www 'Nix systemd service wrapper for geomyidae' 'https://github.com/nqpz/nielx/blob/master/nielx/geomyidae.nix')
$(link_www 'Nix'"'"' declarative requirements for building my gopherhole' 'https://git.metanohi.name/ngws/metanohi-gopher/src/branch/main/shell.nix')


$(header Cool links)

$(link_ext 'Troels Henriksen'"'"'s OCaml Reference' '/ocaml' sigkill.dk)


$(header Contact)

Name: Niels G. W. Serup
$(link_www 'Email: ngws@metanohi.name' 'mailto:ngws@metanohi.name')
IRC: ngws on libera.chat (mostly hanging out on the #diku channel)
$(link_www 'WWW: metanohi.name' 'http://metanohi.name/')
$(link_www 'Twitter: @ngwwws' 'https://twitter.com/ngwwws')
EOF
